@@ -30,6 +30,7 @@
 #include <libintl.h>
 #include <errno.h>
 
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gconf/gconf-client.h>
@@ -2402,12 +2403,13 @@ static void iff_with_filename (char *uri, void *unused);
 static void iff_end (bool success, void *unused);
 
 void
-install_from_file_flow (const char *filename)
+install_from_file_flow (const char *filename,
+                        bool trusted)
 {
   if (start_interaction_flow ())
     {
       if (filename == NULL)
-	show_deb_file_chooser (iff_with_filename, NULL);
+	show_deb_file_chooser (iff_with_filename, GINT_TO_POINTER (trusted));
       else
 	{
 	  /* Try to convert filename to GnomeVFS uri */
@@ -2421,30 +2423,45 @@ install_from_file_flow (const char *filename)
 	      fileuri = g_strdup (filename);
 	    }
 
-	  iff_with_filename (fileuri, NULL);
+	  iff_with_filename (fileuri, GINT_TO_POINTER (trusted));
 	}
     }
 }
 
 static void
-iff_with_filename (char *uri, void *unused)
+iff_with_filename (char *uri, void *data)
 {
   if (uri)
     {
-      install_file (uri, iff_end, NULL);
-      g_free (uri);
+      gboolean trusted = GPOINTER_TO_INT (data);
+      install_file (uri, trusted, iff_end, uri);
     }
   else
     iff_end (false, NULL);
 }
 
 static void
-iff_end (bool success, void *unused)
+iff_end (bool success, void *data)
 {
   end_interaction_flow ();
 
   /* Make sure packages list is initialized after this */
   maybe_init_packages_list ();
+
+  /* This is an incredibly ugly hack needed to be sure that packages
+   * installed from the browser are not left around on disk. Forgive
+   * me for my sins. */
+  char *uri = (char *) data;
+  if (uri)
+    {
+      char *filename = g_filename_from_uri (uri, NULL, NULL);
+      if (filename && g_str_has_prefix (filename, "/var/tmp/"))
+        {
+          g_unlink (filename);
+          g_free (filename);
+        }
+      g_free (uri);
+    }
 }
 
 static void
